<?php

/**
 * @file
 * Hooks provided by the VirusTotal API module.
 *
 * This file contains no working PHP code; it exists to provide additional
 * documentation for doxygen as well as to document hooks in the standard
 * Drupal manner.
 */

/**
 * @addtogroup hooks
 * @{
 * Hooks that can be implemented by other modules in order to extend VirusTotal API.
 */

/**
 * The API request is about to be send.
 *
 * Modules may make changes to the query data before it is send to VirusTotal.
 *
 * @param $data
 *   An array containing request data as name/value pairs.
 * @param $function
 *   The API function name.
 */
function hook_virustotal_query_alter($data, $function) {
  // Print a status message containing the requested report ressource ID.
  if ($function == 'get_url_report' || $function == 'get_file_report') {
    drupal_set_message(t('Requested resource: @resource', array('@resource' => $data['resource'])));
  }
}

/**
 * The API response data is about to be returned.
 *
 * Modules may make changes to the response data before it is returned.
 *
 * @param $result_data
 *   An array containing decoded json response data.
 *   It will at least have a 'result' key, containing a status code.
 * @param $function
 *   The API function name.
 */
function hook_virustotal_result_alter($result_data, $function) {
  // Check result status code and print a status message.
  switch ($result_data['result']) {
    case VIRUSTOTAL_RESULT_OK:
      drupal_set_message(t('Request was valid and could be processed successfully.'));
      break;
    case VIRUSTOTAL_RESULT_EXCEED_QUOTA:
      drupal_set_message(t('Quota was exceeded, the request could not be processed.'), 'error');
      break;
    default:
      drupal_set_message(t('An error occurred, the request could not be processed.'), 'error');
      break;
  }
}

/**
 * @} End of "addtogroup hooks".
 */
